/* crlfetch.c - LDAP access
 *      Copyright (C) 2002 Klarlvdalens Datakonsult AB
 *
 * This file is part of DirMngr.
 *
 * DirMngr is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * DirMngr is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 */

#include <config.h>

#include <stdio.h>

#include "crlfetch.h"
#include "dirmngr.h"


/* Fetch CRL from URL and return the entire CRL in a newly allocated
   buffer assigned to VALUE and assign the length of this CRL to
   VALUELEN. */
gpg_error_t
crl_fetch (const char *issuer, unsigned char **value, size_t * valuelen)
{
  int rc;
  
  *value = NULL;
  rc = url_fetch_ldap (issuer, "certificateRevocationList;binary", value,
                       valuelen);
  if (rc && *value)
    {
      xfree (*value);
      *value = NULL;
      *valuelen = 0;
    }
  return rc;
}

/* Fetch CRL for ISSUER using a default server. Return the entire CRL
   in a newly allocated buffer assigned to VALUE and assign the length
   of this CRL to VALUELEN. */
gpg_error_t
crl_fetch_default (const char *issuer, unsigned char **value, size_t * valuelen)
{
  int rc;
  
  *value = NULL;
  rc = attr_fetch_ldap (issuer, "certificateRevocationList;binary", value,
                        valuelen);
  if (rc && *value)
    {
      xfree (*value);
      *value = NULL;
      *valuelen = 0;
    }
  return rc;
}


/* Fetch a CA certificate for DN using the default server. */
int
ca_cert_fetch (const char *dn, unsigned char **value, size_t *valuelen)
{
  int rc;

  *value = NULL;
  rc = attr_fetch_ldap (dn, "cACertificate;binary", value, valuelen);
  if (rc && *value)
    {
      xfree (*value);
      *value = NULL;
      *valuelen = 0;
    }
  return rc;
}


gpg_error_t
start_cert_fetch (cert_fetch_context_t *context,
                  strlist_t patterns, const ldap_server_t server)
{
  return start_cert_fetch_ldap (context, patterns, server);
}

gpg_error_t
fetch_next_cert (cert_fetch_context_t context,
                 unsigned char **value, size_t * valuelen)
{
  return fetch_next_cert_ldap (context, value, valuelen);
}

void
end_cert_fetch (cert_fetch_context_t context)
{
  return end_cert_fetch_ldap (context);
}
